@@ -15,30 +15,32 @@ from oort.shared.identity import Identity
 from oort.shared.models import Organisation
 
 
-def check_local_astronomer(debug: bool):
+def check_local_astronomer(debug: bool, verbose: bool):
     test = os.environ.get('OORT_TESTS') == '1'
-    username = ArcsecondAPI.username(debug=debug, test=test)
+
+    username = ArcsecondAPI.username(debug=debug, test=test, verbose=verbose)
     if username is None:
         raise InvalidAstronomerOortCloudError('')
-    upload_key = ArcsecondAPI.upload_key(debug=debug, test=test)
+
+    upload_key = ArcsecondAPI.upload_key(debug=debug, test=test, verbose=verbose)
     return username, upload_key
 
 
-def check_remote_organisation(org_subdomain: str, debug: bool):
+def check_remote_organisation(org_subdomain: str, debug: bool, verbose: bool):
     try:
         return Organisation.get(subdomain=org_subdomain)
     except DoesNotExist:
         test = os.environ.get('OORT_TESTS') == '1'
-        org_resource, error = ArcsecondAPI.organisations(debug=debug, test=test).read(org_subdomain)
+        org_resource, error = ArcsecondAPI.organisations(debug=debug, test=test, verbose=verbose).read(org_subdomain)
         if error:
             raise UnknownOrganisationOortCloudError(org_subdomain, str(error))
         else:
             return Organisation.smart_create(subdomain=org_subdomain)
 
 
-def check_local_astronomer_remote_organisation_membership(org_subdomain: str, debug: bool) -> str:
+def check_local_astronomer_remote_organisation_membership(org_subdomain: str, debug: bool, verbose: bool) -> str:
     test = os.environ.get('OORT_TESTS') == '1'
-    memberships = ArcsecondAPI.memberships(debug=debug, test=test) if org_subdomain else None
+    memberships = ArcsecondAPI.memberships(debug=debug, test=test, verbose=verbose) if org_subdomain else None
     if org_subdomain and memberships in [None, {}]:
         raise InvalidOrgMembershipOortCloudError(org_subdomain)
 
@@ -49,12 +51,15 @@ def check_local_astronomer_remote_organisation_membership(org_subdomain: str, de
     return role
 
 
-def list_organisation_telescopes(org_subdomain: str, debug: bool):
+def list_organisation_telescopes(org_subdomain: str, debug: bool, verbose: bool):
     click.echo("Error: if an organisation is provided, you must specify a telescope UUID.")
     click.echo(f"Here is a list of existing telescopes for organisation {org_subdomain}:")
 
     test = os.environ.get('OORT_TESTS') == '1'
-    telescope_list, error = ArcsecondAPI.telescopes(debug=debug, test=test, organisation=org_subdomain).list()
+    telescope_list, error = ArcsecondAPI.telescopes(organisation=org_subdomain,
+                                                    debug=debug,
+                                                    test=test,
+                                                    verbose=verbose).list()
     for telescope in telescope_list:
         click.echo(f" • {telescope['name']} ({telescope['uuid']})")
 
@@ -63,11 +68,12 @@ def list_organisation_telescopes(org_subdomain: str, debug: bool):
 # also in the case of a custom astronomer.
 def check_organisation_telescope(telescope_uuid: Optional[Union[str, UUID]],
                                  org_subdomain: Optional[str],
-                                 debug: bool) -> Optional[dict]:
+                                 debug: bool,
+                                 verbose: bool) -> Optional[dict]:
     click.echo("Fetching telescope details...")
 
     test = os.environ.get('OORT_TESTS') == '1'
-    kwargs = {'debug': debug, 'test': test}
+    kwargs = {'debug': debug, 'test': test, 'verbose': verbose}
     if org_subdomain:
         kwargs.update(organisation=org_subdomain)
 
@@ -84,21 +90,22 @@ def check_organisation_telescope(telescope_uuid: Optional[Union[str, UUID]],
     return telescope_detail
 
 
-def check_remote_astronomer(username: str, upload_key: str, debug: bool):
+def check_remote_astronomer(username: str, upload_key: str, debug: bool, verbose: bool):
     click.echo("Checking astronomer credentials...")
 
     if username is None or upload_key is None:
         raise InvalidWatchOptionsOortCloudError()
 
     test = os.environ.get('OORT_TESTS') == '1'
-    result, error = ArcsecondAPI.me(debug=debug, test=test).read(username)
+    result, error = ArcsecondAPI.me(debug=debug, test=test, verbose=verbose).read(username)
     if error:
         raise InvalidAstronomerOortCloudError(username, upload_key, error_string=str(error))
 
 
-def check_organisation_uploadkeys(org_subdomain: str, username: str, upload_key: str, debug: bool):
+def check_organisation_uploadkeys(org_subdomain: str, username: str, upload_key: str, debug: bool, verbose: bool):
     test = os.environ.get('OORT_TESTS') == '1'
-    kwargs = {'debug': debug, 'test': test, 'organisation': org_subdomain}
+    kwargs = {'debug': debug, 'test': test, 'verbose': verbose, 'organisation': org_subdomain}
+
     upload_keys_details, error = ArcsecondAPI.uploadkeys(**kwargs).list()
     if error:
         InvalidWatchOptionsOortCloudError(str(error))
@@ -118,7 +125,8 @@ def parse_upload_watch_options(o: Optional[str] = None,
                                t: Optional[str] = None,
                                telescope: Optional[str] = None,
                                astronomer: Union[Optional[str], Optional[str]] = (None, None),
-                               debug: Optional[bool] = False):
+                               debug: Optional[bool] = False,
+                               verbose: Optional[bool] = False):
     telescope_uuid = t or telescope or ''
     org_subdomain = o or organisation or ''
 
@@ -128,16 +136,16 @@ def parse_upload_watch_options(o: Optional[str] = None,
     org_role = ''
     if org_subdomain:
         # Check that the provided subdomain corresponds to an existing remote organisation.
-        org = check_remote_organisation(org_subdomain, debug)
+        org = check_remote_organisation(org_subdomain, debug, verbose)
         # Check that the provided subdomain is an organisation of which the current logged in astronomer is a member.
-        org_role = check_local_astronomer_remote_organisation_membership(org_subdomain, debug)
+        org_role = check_local_astronomer_remote_organisation_membership(org_subdomain, debug, verbose)
 
     ### Validation of the telescope ###
 
     # In every case, check for telescope details if a UUID is provided.
     telescope_details = None
     if telescope_uuid:
-        telescope_details = check_organisation_telescope(telescope_uuid, org_subdomain, debug)
+        telescope_details = check_organisation_telescope(telescope_uuid, org_subdomain, debug, verbose)
 
     ### Validation of the uploader ###
 
@@ -147,28 +155,28 @@ def parse_upload_watch_options(o: Optional[str] = None,
     # No custom astronomer for uploading. If no org, fine. If an org, one need the telescope.
     if astronomer == (None, None):
         # Fetch the username of the currently logged in astronomer.
-        username, upload_key = check_local_astronomer(debug)
+        username, upload_key = check_local_astronomer(debug, verbose)
         if not username or not upload_key:
             raise InvalidWatchOptionsOortCloudError('Missing username or upload_key.')
 
         # If we have an organisation and no telescope UUID, we list the one available
         # and then raise an error
         if org is not None and telescope_details is None:
-            list_organisation_telescopes(org_subdomain, debug)
+            list_organisation_telescopes(org_subdomain, debug, verbose)
             raise InvalidWatchOptionsOortCloudError('For an organisation, a telescope UUID must be provided.')
 
     # We have a custom astronomer. Check that the organisation is allowed to upload on behalf of it.
     else:
         username, upload_key = astronomer
         # Make sure the remote astronomer actually exists.
-        check_remote_astronomer(username, upload_key, debug)
+        check_remote_astronomer(username, upload_key, debug, verbose)
 
         if org is None:
             raise InvalidWatchOptionsOortCloudError('')
 
         # Check that the custom astronomer has a valid upload_key for the given organisation.
         # This is where the knot is. This check can only be made by a member of the registered organisation.
-        check_organisation_uploadkeys(org_subdomain, username, upload_key, debug)
+        check_organisation_uploadkeys(org_subdomain, username, upload_key, debug, verbose)
 
     return username, upload_key, org_subdomain, org_role, telescope_details
 
@@ -179,7 +187,8 @@ def save_upload_folders(folders: list,
                         org_subdomain: Optional[str],
                         org_role: Optional[str],
                         telescope_details: Optional[dict],
-                        debug: bool) -> list:
+                        debug: bool,
+                        verbose: bool) -> list:
     logger = get_logger('cli', debug=debug)
     prepared_folders = []
     for raw_folder in folders:
