@@ -66,7 +66,7 @@ class UploadPack(object):
         self._root_path = root_path
         self._raw_file_path = pathlib.Path(file_path)
 
-        self._logger = get_logger(debug=True)
+        self._logger = get_logger('uloader', debug=identity.debug)
         self._parse()
 
         # Will work whatever the raw file path extension (zipped or not), and
@@ -76,14 +76,12 @@ class UploadPack(object):
 
         self._find_date_and_sizes()
 
-    def do_zip(self):
-        if not self.should_zip:
+    def do_upload(self):
+        if self.should_zip:
+            zip = zipper.AsyncZipper(self.clear_file_path)
+            zip.start()
             return
 
-        zip = zipper.AsyncZipper(self.clear_file_path)
-        zip.start()
-
-    def do_upload(self):
         if self.is_data_file and self._upload.file_size_zipped == 0 and self._upload.substatus == Substatus.READY.value:
             self._logger.info(f'{self.log_prefix} {self.zipped_file_path} is zipped but size is zero?')
             return
@@ -265,14 +263,18 @@ class UploadPack(object):
         hdulist = None
         try:
             with pyfits.open(path, mode='readonly', memmap=True, ignore_missing_end=True) as hdulist:
-                for hdu in hdulist:
-                    date_header = hdu.header.get('DATE') or hdu.header.get('DATE-OBS') or hdu.header.get('DATE_OBS')
-                    if not date_header:
-                        continue
-                    file_date = dateparser.parse(date_header)
-                    if file_date:
-                        hdulist.close()
+                for index, hdu in enumerate(hdulist):
+                    # Breaking after 10 HDUs as a workaround to corrupted FITS files that end up in
+                    # an infinite loop of HDU reading. Note that relying on len(hdulist) is a BAD
+                    # idea as it required to force the reading of all HDUs (lazy loaded by default).
+                    if index >= 10:
                         break
+                    date_header = hdu.header.get('DATE') or hdu.header.get('DATE-OBS') or hdu.header.get('DATE_OBS')
+                    if date_header:
+                        file_date = dateparser.parse(date_header)
+                        if file_date:
+                            hdulist.close()
+                            break
         except Exception as error:
             if hdulist:
                 hdulist.close()
